@@ -9,8 +9,9 @@ from pathlib import Path, PurePath
 from typing import Optional, Tuple
 from urllib.parse import urlsplit
 
-from git import GitCommandError, InvalidGitRepositoryError, Repo, TagObject
+from git import GitCommandError, InvalidGitRepositoryError, Repo
 from git.exc import BadName
+from git.objects import TagObject
 
 from .errors import GitError, HvcsRepoParseError
 from .helpers import LoggedFunction
@@ -19,7 +20,7 @@ from .settings import config
 try:
     repo = Repo(".", search_parent_directories=True)
 except InvalidGitRepositoryError:
-    repo = None
+    pass
 
 logger = logging.getLogger(__name__)
 
@@ -36,11 +37,18 @@ def check_repo(func):
     return function_wrapper
 
 
+def get_formatted_tag(version):
+    """Get the version, formatted with `tag_format` config option"""
+    tag_format = config.get("tag_format")
+    return tag_format.format(version=version)
+
+
 @check_repo
 def get_commit_log(from_rev=None):
     """Yield all commit messages from last to first."""
     rev = None
     if from_rev:
+        from_rev = get_formatted_tag(from_rev)
         try:
             repo.commit(from_rev)
             rev = f"...{from_rev}"
@@ -69,10 +77,9 @@ def get_last_version(skip_tags=None) -> Optional[str]:
         return tag.commit.committed_date
 
     for i in sorted(repo.tags, reverse=True, key=version_finder):
-        if re.match(r"v\d+\.\d+\.\d+", i.name):  # Matches vX.X.X
-            if i.name in skip_tags:
-                continue
-            return i.name[1:]  # Strip off 'v'
+        match = re.search(r"\d+\.\d+\.\d+", i.name)
+        if match and i.name not in skip_tags:
+            return match.group(0)  # Return only numeric vesion like 1.2.3
 
     return None
 
@@ -147,7 +154,7 @@ def commit_new_version(version: str):
     )
 
     for declaration in load_version_declarations():
-        git_path = PurePath(os.getcwd(), declaration.path).relative_to(repo.working_dir)
+        git_path: PurePath = PurePath(os.getcwd(), declaration.path).relative_to(repo.working_dir)  # type: ignore
         repo.git.add(str(git_path))
 
     return repo.git.commit(m=message, author=commit_author)
@@ -190,18 +197,19 @@ def update_changelog_file(version: str, content_to_add: str):
         ),
     )
     git_path.write_text(updated_content)
-    repo.git.add(str(git_path.relative_to(repo.working_dir)))
+    repo.git.add(str(git_path.relative_to(repo.working_dir)))  # type: ignore
 
 
 @check_repo
 @LoggedFunction(logger)
 def tag_new_version(version: str):
     """
-    Create a new tag with the version number, prefixed with v.
+    Create a new tag with the version number, prefixed with v by default.
 
     :param version: The version number used in the tag as a string.
     """
-    return repo.git.tag("-a", f"v{version}", m=f"v{version}")
+    tag = get_formatted_tag(version)
+    return repo.git.tag("-a", tag, m=tag)
 
 
 @check_repo
